# n8n Chat

A Drupal module that integrates n8n chat widget functionality into your Drupal site, providing seamless chat experiences powered by n8n workflows.

## Features

- **Easy Integration**: Simple setup with n8n webhook URLs
- **Flexible Placement**: Use as a global widget or place specific blocks
- **Responsive Design**: Works on desktop and mobile devices
- **Customizable Appearance**: Light/dark themes and custom CSS support
- **Session Management**: Automatic session tracking with unique session IDs
- **Conversation History**: Persistent sessions with 24-hour expiry
- **New Conversation**: Users can start fresh conversations anytime
- **AI Integration**: Works with Drupal's AI Chatbot module
- **User Context**: Optional user information sharing with n8n workflows

## Installation

1. Place this module in your `web/modules/custom/` directory
2. Enable the module: `drush en n8n_chat`
3. Configure the module at `/admin/config/services/n8n-chat`

## Configuration

### Global Widget
- Navigate to **Administration > Configuration > Web services > n8n Chat**
- Enable "Enable global chat widget" to show the widget on all pages
- Enter your n8n webhook URL
- Customize appearance settings

### Block Placement
- Navigate to **Administration > Structure > Block layout**
- Place the "n8n Chat" block in your desired region
- Configure block-specific settings

## n8n Workflow Setup

Your n8n workflow should:

1. **Start with a Chat Trigger node** - The payload format is designed to work with n8n's Chat Trigger node by default
2. **Expect JSON payload** with these fields:
   ```json
   {
     "chatInput": "User's message text",
     "timestamp": "2024-01-01T12:00:00.000Z",
     "sessionId": "chat_1704110400000_abc123def",
     "userId": "123" // or "anonymous"
   }
   ```
3. **Return JSON response** with:
   ```json
   {
     "output": "Bot response text"
   }
   ```

### Example n8n Workflow

1. **Chat Trigger**: Use n8n's Chat Trigger node (recommended) or configure a Webhook node to accept POST requests
2. **Process Message**: Add your logic (AI, database lookup, etc.)
3. **Respond**: Return formatted response

**Tip**: The payload format is optimized for n8n's Chat Trigger node, which provides better integration and built-in chat functionality compared to using generic webhook nodes.

## Session Management

The widget automatically manages conversation sessions:

### Session ID Generation
- **Unique IDs**: Each conversation gets a unique session ID (format: `chat_timestamp_randomstring`)
- **Persistent Storage**: Session IDs are stored in browser localStorage
- **Auto-Expiry**: Sessions automatically expire after 24 hours

### Session Features
- **Flexible Session Behavior**: Choose how sessions are handled on page load
  - **Always New**: Start fresh conversation each time (default)
  - **Continue Session**: Maintain session across page reloads
  - **Load History**: Continue session and restore previous messages
- **Conversation History**: Load previous messages from n8n memory
- **New Conversation Button**: Users can manually start fresh conversations
- **Automatic Cleanup**: Expired sessions are automatically reset

### Using Session Data in n8n
Use the `sessionId` field to:
- **Track Conversations**: Group related messages together
- **Maintain Context**: Store conversation history in your database
- **Personalization**: Remember user preferences per session
- **Analytics**: Track conversation patterns and duration

### Conversation History API
To support conversation history, your n8n workflow should handle:

**History Request** (sent when loading the widget):
```json
{
  "action": "getHistory",
  "sessionId": "chat_1704110400000_abc123def",
  "userId": "123"
}
```

**History Response** (return previous messages):
```json
{
  "history": [
    {
      "type": "user",
      "message": "Hello",
      "timestamp": "2024-01-01T12:00:00.000Z"
    },
    {
      "type": "bot",
      "message": "Hi! How can I help?",
      "timestamp": "2024-01-01T12:00:05.000Z"
    }
  ]
}
```

## Customization

### CSS Customization
Add custom CSS in the module settings or block configuration:

```css
.n8n-chat .chat-toggle {
  background: #your-brand-color;
}

.n8n-chat .chat-window {
  border-radius: 15px;
}
```

### JavaScript Events
The widget triggers custom events you can listen to:

```javascript
document.addEventListener('n8nChatMessage', function(event) {
  console.log('Message sent:', event.detail.chatInput);
});

document.addEventListener('n8nChatResponse', function(event) {
  console.log('Response received:', event.detail.response);
});
```

## Integration with AI Chatbot Module

When AI integration is enabled, the widget can:
- Share conversation context with Drupal's AI system
- Fallback to local AI when n8n is unavailable
- Provide enhanced user experience

## Troubleshooting

### Widget Not Appearing
1. Check that the module is enabled
2. Verify webhook URL is configured
3. Check browser console for JavaScript errors
4. Ensure the block is placed in a visible region

### Messages Not Sending
1. Verify n8n webhook URL is accessible
2. Check n8n workflow is active
3. Review browser network tab for failed requests
4. Enable debug mode for additional logging

### Styling Issues
1. Check for CSS conflicts with your theme
2. Use browser developer tools to inspect elements
3. Add custom CSS to override default styles

## Security Considerations

- **Webhook URLs**: Keep your n8n webhook URLs secure
- **User Data**: Be mindful of what user information you send to n8n
- **CORS**: Ensure your n8n instance allows requests from your domain
- **Rate Limiting**: Consider implementing rate limiting in your n8n workflow

## Development with Generative AI

This module was primarily generated and is maintained using generative AI tools. This approach enables:

- **Rapid Development**: Quick iteration and feature implementation
- **Code Quality**: AI-assisted code review and optimization
- **Documentation**: Comprehensive and up-to-date documentation
- **Best Practices**: Adherence to Drupal coding standards and security practices

## Support

For issues and feature requests, please contact your development team or check the module's documentation.
