<?php

namespace Drupal\Tests\n8n_chat\Unit;

use Drupal\Tests\UnitTestCase;

/**
 * Simple test to verify testing framework is working.
 *
 * @group n8n_chat
 */
class SimpleTest extends UnitTestCase {

  /**
   * Tests basic functionality.
   */
  public function testBasicFunctionality() {
    // Test that module name is correct.
    $this->assertEquals('n8n_chat', 'n8n_chat');
  }

  /**
   * Tests URL validation function.
   */
  public function testUrlValidation() {
    // Test valid URLs.
    $this->assertTrue(filter_var('https://example.com/webhook', FILTER_VALIDATE_URL) !== FALSE);
    $this->assertTrue(filter_var('http://localhost:3000/webhook', FILTER_VALIDATE_URL) !== FALSE);

    // Test invalid URLs.
    $this->assertFalse(filter_var('invalid-url', FILTER_VALIDATE_URL) !== FALSE);
    $this->assertFalse(filter_var('', FILTER_VALIDATE_URL) !== FALSE);
  }

  /**
   * Tests configuration schema structure.
   */
  public function testConfigurationStructure() {
    $expected_config_keys = [
      'enable_global_widget',
      'webhook_url',
      'widget_title',
      'widget_position',
      'widget_theme',
      'custom_css',
      'debug_mode',
      'ai_integration',
      'user_context',
      'session_behavior',
      'history_support',
    ];

    // Test that we have all expected configuration keys.
    $this->assertCount(11, $expected_config_keys);
    $this->assertContains('webhook_url', $expected_config_keys);
    $this->assertContains('widget_title', $expected_config_keys);
  }

  /**
   * Tests widget position options.
   */
  public function testWidgetPositionOptions() {
    $valid_positions = [
      'bottom-right',
      'bottom-left',
      'top-right',
      'top-left',
    ];

    $this->assertContains('bottom-right', $valid_positions);
    $this->assertContains('bottom-left', $valid_positions);
    $this->assertNotContains('center', $valid_positions);
  }

  /**
   * Tests widget theme options.
   */
  public function testWidgetThemeOptions() {
    $valid_themes = [
      'light',
      'dark',
    ];

    $this->assertContains('light', $valid_themes);
    $this->assertContains('dark', $valid_themes);
    $this->assertNotContains('blue', $valid_themes);
  }

  /**
   * Tests session behavior options.
   */
  public function testSessionBehaviorOptions() {
    $valid_behaviors = [
      'refresh',
      'persist',
      'load_history',
    ];

    $this->assertContains('refresh', $valid_behaviors);
    $this->assertContains('persist', $valid_behaviors);
    $this->assertContains('load_history', $valid_behaviors);
  }

}
